%define upstream_name    Encode
%define upstream_version 3.08

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
%define     subrel 1
Release:    %mkrel 1
Summary:    Character Encodings Handler
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/D/DA/DANKOGAI/%{upstream_name}-%{upstream_version}.tar.gz

#
# Security Patches
# P100 -> ...
#
# CVE-2021-36770
Patch100:      527e482dc70b035d0df4f8c77a00d81f8d775c74.patch
BuildRequires: perl(Exporter) >= 5.570.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Storable)
BuildRequires: perl(Test::More) >= 0.920.0
BuildRequires: perl(parent) >= 0.221.0
BuildRequires: perl-devel
Requires:   perl-devel
%{?perl_default_filter}

%description
The "Encode" module provides the interfaces between Perl's strings and
the rest of the system.  Perl strings are sequences of characters.

The repertoire of characters that Perl can represent is at least that
defined by the Unicode Consortium. On most platforms the ordinal values
of the characters (as returned by "ord(ch)") is the "Unicode codepoint"
for the character (the exceptions are those platforms where the legacy
encoding is some variant of EBCDIC rather than a super-set of ASCII -
see perlebcdic).

Traditionally, computer data has been moved around in 8-bit chunks often
called "bytes". These chunks are also known as "octets" in networking
standards. Perl is widely used to manipulate data of many types - not
only strings of characters representing human or computer languages but
also "binary" data being the machine's representation of numbers, pixels
in an image - or just about anything.

When Perl is processing "binary data", the programmer wants Perl to
process "sequences of bytes". This is not a problem for Perl - as a byte
has 256 possible values, it easily fits in Perl's much larger "logical
character".

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%autopatch -p1

%build
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install
rm -rf %buildroot/usr/bin

%files
%doc AUTHORS CN Changes EBCDIC JP KR META.json META.yml MYMETA.yml README TW
%{_mandir}/man1/enc2xs.1*
%{_mandir}/man1/encguess.1*
%{_mandir}/man1/piconv.1*
%{_mandir}/man3/*
%{perl_vendorarch}/Encode
%{perl_vendorarch}/Encode.pm
%{perl_vendorarch}/encoding.pm
%{perl_vendorarch}/auto/Encode


%changelog
* Fri Nov 26 2021 neoclust <neoclust> 3.80.0-1.1.mga8
+ Revision: 1759351
- Add P100: Fixes CVE-2021-36770 (mga#29352)

* Thu Dec 03 2020 tv <tv> 3.80.0-1.mga8
+ Revision: 1652071
- update to 3.08

* Sat Aug 01 2020 tv <tv> 3.70.0-1.mga8
+ Revision: 1610199
- update to 3.07

* Wed Jun 17 2020 umeabot <umeabot> 3.60.0-2.mga8
+ Revision: 1594578
- Rebuild for perl 5.32

* Sun May 03 2020 tv <tv> 3.60.0-1.mga8
+ Revision: 1578010
- update to 3.06

* Thu Mar 19 2020 tv <tv> 3.50.0-1.mga8
+ Revision: 1557883
- update to 3.05

* Thu Mar 12 2020 tv <tv> 3.40.0-1.mga8
+ Revision: 1555712
- update to 3.04

* Tue Mar 03 2020 tv <tv> 3.30.0-1.mga8
+ Revision: 1553342
- update to 3.03

* Tue Feb 18 2020 umeabot <umeabot> 3.20.0-2.mga8
+ Revision: 1541397
- Mageia 8 Mass Rebuild

* Thu Dec 26 2019 tv <tv> 3.20.0-1.mga8
+ Revision: 1470164
- update to 3.02

* Tue Aug 27 2019 tmb <tmb> 3.10.0-2.mga8
+ Revision: 1433581
- rebuild for perl 5.30

* Fri Mar 15 2019 tv <tv> 3.10.0-1.mga7
+ Revision: 1377495
- update to 3.01

* Thu Jan 31 2019 tv <tv> 3.0.0-1.mga7
+ Revision: 1362159
- update to 3.00

* Mon Jan 21 2019 tv <tv> 2.990.0-1.mga7
+ Revision: 1358789
- update to 2.99

* Fri Sep 21 2018 umeabot <umeabot> 2.980.0-3.mga7
+ Revision: 1292829
- Mageia 7 Mass Rebuild

* Mon Aug 06 2018 guillomovitch <guillomovitch> 2.980.0-2.mga7
+ Revision: 1248349
- fix files list

* Mon Apr 23 2018 shlomif <shlomif> 2.980.0-1.mga7
+ Revision: 1221558
- update to 2.98

* Sun Feb 25 2018 shlomif <shlomif> 2.970.0-1.mga7
+ Revision: 1204933
- update to 2.97

* Wed Jan 17 2018 kekepower <kekepower> 2.940.0-1.mga7
+ Revision: 1194093
- Update to version 2.94

* Tue Oct 24 2017 shlomif <shlomif> 2.930.0-1.mga7
+ Revision: 1173443
- update to 2.93

* Mon Oct 02 2017 tv <tv> 2.920.0-3.mga7
+ Revision: 1164292
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 2.920.0-2.mga7
+ Revision: 1148875
- Rebuild for perl ABI changes

* Mon Jul 24 2017 sander85 <sander85> 2.920.0-1.mga7
+ Revision: 1130024
- update to 2.92
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 2.840.0-2.mga6
+ Revision: 1026916
- Rebuild for perl 5.22.2

* Fri Apr 15 2016 shlomif <shlomif> 2.840.0-1.mga6
+ Revision: 1001910
- New version 2.84

* Fri Feb 12 2016 umeabot <umeabot> 2.780.0-2.mga6
+ Revision: 957239
- Mageia 6 Mass Rebuild

* Mon Sep 28 2015 sander85 <sander85> 2.780.0-1.mga6
+ Revision: 884563
- update to 2.78

* Sat Aug 01 2015 sander85 <sander85> 2.760.0-1.mga6
+ Revision: 860332
- update to 2.76

* Mon Jul 06 2015 sander85 <sander85> 2.750.0-1.mga6
+ Revision: 851880
- update to 2.75

* Thu Jun 25 2015 sander85 <sander85> 2.730.0-1.mga6
+ Revision: 843749
- update to 2.73

* Wed Oct 15 2014 umeabot <umeabot> 2.620.0-4.mga5
+ Revision: 750796
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 2.620.0-3.mga5
+ Revision: 732095
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 2.620.0-2.mga5
+ Revision: 684633
- Mageia 5 Mass Rebuild

* Wed Jun 04 2014 sander85 <sander85> 2.620.0-1.mga5
+ Revision: 632900
- update to 2.62

* Tue Jun 03 2014 pterjan <pterjan> 2.600.0-2.mga5
+ Revision: 631132
- Rebuild for perl 5.20

* Tue May 06 2014 jquelin <jquelin> 2.600.0-1.mga5
+ Revision: 620424
- update to 2.60

* Tue Apr 15 2014 jquelin <jquelin> 2.590.0-1.mga5
+ Revision: 614590
- update to 2.59

* Tue Apr 01 2014 jquelin <jquelin> 2.580.0-1.mga5
+ Revision: 611105
- update to 2.58

* Sun Feb 09 2014 sander85 <sander85> 2.570.0-1.mga5
+ Revision: 587322
- update to 2.57

* Sat Oct 19 2013 umeabot <umeabot> 2.550.0-2.mga4
+ Revision: 534782
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 sander85 <sander85> 2.550.0-1.mga4
+ Revision: 478853
- update to 2.55

* Thu Aug 29 2013 sander85 <sander85> 2.540.0-1.mga4
+ Revision: 473114
- update to 2.54

* Wed Aug 14 2013 sander85 <sander85> 2.520.0-1.mga4
+ Revision: 466372
- update to 2.52

* Mon Jun 03 2013 jquelin <jquelin> 2.510.0-1.mga4
+ Revision: 436409
- update to 2.51

* Wed May 29 2013 jquelin <jquelin> 2.470.0-5.mga4
+ Revision: 430689
- perl 5.18.0 rebuild

* Wed Mar 27 2013 jquelin <jquelin> 2.470.0-4.mga3
+ Revision: 405473
- perl 5.16.3 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 2.470.0-3.mga3
+ Revision: 366871
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 jquelin <jquelin> 2.470.0-2.mga3
+ Revision: 315499
- perl 5.16.2 rebuild

* Mon Aug 27 2012 jquelin <jquelin> 2.470.0-1.mga3
+ Revision: 284603
- update to 2.47

* Wed May 30 2012 jquelin <jquelin> 2.440.0-3.mga3
+ Revision: 250583
- rebuild for perl 5.16

* Fri Nov 04 2011 jquelin <jquelin> 2.440.0-2.mga2
+ Revision: 162804
- take priority over module bundled with perl 5.14.2
+ kharec <kharec>
- update to 2.44

* Wed Jun 22 2011 jquelin <jquelin> 2.430.0-1.mga2
+ Revision: 112055
- update to 2.43

* Sat Jun 11 2011 sander85 <sander85> 2.420.0-3.mga2
+ Revision: 104235
- perl 5.14

* Fri Feb 18 2011 jquelin <jquelin> 2.420.0-2.mga1
+ Revision: 53608
- rebuild

* Fri Jan 21 2011 jquelin <jquelin> 2.420.0-1.mga1
+ Revision: 30184
- mageia rebuild
- imported package perl-Encode

